/*
 * Arquivo: aleatorio.c
 * --------------
 * Implementa a interface aleatorio.h
 */

#include <stdlib.h>
#include <time.h>
#include "aleatorio.h"

/*
 * Função: Aleatorize
 * -------------------
 * Esta função indica a semente para a geração de números
 * aleatórios para o horário atual.  A função srand é
 * fornecida pela biblioteca <stdlib.h> e requer um 
 * parêmetro inteiro.  A função time é fornecida por
 * <time.h>.
 */

void Aleatorize(void)
{
    srand((int) time(NULL));
}

/*
 * Função: InteiroAleatorio
 * -----------------------
 * Esta função primeiro obtém um inteiro aleatório 
 * no intervalo [0..RAND_MAX] e depois converte-o
 * em um número no intervalo [min..max] aplicando 
 * os seguintes passos:
 * (1) Gera um número real entre 0 e 1.
 * (2) Escala-o para o tamanho apropriado de intervalo.
 * (3) Trunca o valor para um inteiro.
 * (4) Traduz para o ponto de início apropriado.
 */

int InteiroAleatorio(int min, int max)
{
    int k;
    double d;

    d = (double) rand() / ((double) RAND_MAX + 1);
    k = (int) (d * (max - min + 1));
    return (min + k);
}

/*
 * Função: RealAleatorio
 * --------------------
 * A implementação de RealAleatorio é similar a do 
 * InteiroAleatorio, mas sem o passo da truncagem.
 */

double RealAleatorio(double min, double max)
{
    double d;

    d = (double) rand() / ((double) RAND_MAX + 1);
    return (min + d * (max - min));
}

/*
 * Função: SorteAleatoria
 * ----------------------
 * Esta Função usa RealAleatorio para gerar um número 
 * entre 0 e 1, que é então comparado a p.
 */

bool SorteAleatoria(double p)
{
    return (RealAleatorio(0, 1) < p);
}
