/*
 * Arquivo: aleatorio.h
 * --------------
 * Biblioteca para a produção de números pseudo-aleatórios
 */

#ifndef _aleatorio_h
#define _aleatorio_h
#include <stdbool.h>

/*
 * Função: Aleatorize
 * Uso: Aleatorize();
 * -------------------
 * Esta função indica a semente para o rand de forma que a  
 * sequência aleatória seja imprevisível. Durante a fase de 
 * depuração, é melhor não chamar esta função. Assim, o 
 * comportamento do programa sera reprodutível.
 */

void Aleatorize(void);

/*
 * Função: InteiroAleatorio
 * Uso: n = InteiroAleatorio(min, max);
 * ------------------------------------
 * Esta função devolve um inteiro aleatório no intervalo 
 * fechado [min .. max].
 */

int InteiroAleatorio(int min, int max);

/*
 * Função: RealAleatorio
 * Uso: d = RealAleatorio(min, max);
 * ---------------------------------
 * Esta função devolve um número real aleatório no intervalo 
 * semi-fechado [min .. max), significando que o resultado
 * é sempre maior ou igual a min, mas estritamente menor que 
 * max.
 */

double RealAleatorio(double min, double max);

/*
 * Função: SorteAleatoria
 * Uso: if (SorteAleatoria(p)) . . .
 * ---------------------------------
 * A função SorteAleatoria devolve true com a probabilidade
 * indicada por p, que deve ser um numero real entre 0
 * (significando nunca) e 1 (significando sempre). Por 
 * exemplo, a chamada SorteAleatoria(.30) devolve true 
 * 30% das vezes.
 */

bool SorteAleatoria(double p);

#endif
